# `narwhals.dependencies`

::: narwhals.dependencies
    handler: python
    options:
      members:
        - get_pandas
        - get_polars
        - get_modin
        - get_cudf
        - get_pyarrow
      show_source: false
      show_bases: false
